==> owncloud-10.2.0.zip: owncloud/settings/l10n/ro.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Parolă greșită",
    "No user supplied" : "Nu a fost furnizat niciun utilizator",
    "Authentication error" : "Eroare la autentificare",
    "Wrong admin recovery password. Please check the password and try again." : "Parolă administrativă de recuperare greșită. Verifică parola și încearcă din nou.",
    "Unable to change password" : "Imposibil de schimbat parola",
    "Couldn't send reset email. Please contact your administrator." : "Expedierea email-ului de resetare a eşuat. Vă rugăm să contactaţi administratorul dvs.",
    "Federated Cloud Sharing" : "Partajare federalizata cloud",
    "Migration Completed" : "Migrare încheiată",
    "Group already exists." : "Grupul există deja.",
    "Unable to add group." : "Nu se poate adăuga grupul.",
    "Unable to delete group." : "Nu se poate șterge grupul.",
    "log-level out of allowed range" : "NIvelul de logare este în afara plajei admise",
    "Saved" : "Salvat",
    "test email settings" : "verifică setările de e-mail",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : " A apărut o problemă la trimiterea emailului. Verifică-ți setărie. (Eroare: %s)",
    "Email sent" : "Mesajul a fost expediat",
    "You need to set your user email before being able to send test emails." : "Trebuie să îți setezi emailul de utilizator înainte de a putea să trimiți emailuri.",
    "Invalid mail address" : "Adresa mail invalidă",
    "A user with that name already exists." : "Există deja un utilizator cu acest nume.",
    "Unable to create user." : "Imposibil de creat utilizatorul.",
    "Your %s account was created" : "Contul tău %s a fost creat",
    "Unable to delete user." : "Imposibil de șters utilizatorul.",
    "Forbidden" : "Interzis",
    "Invalid user" : "Utilizator invalid",
    "Unable to change mail address" : "Nu s-a putut schimba adresa email",
    "Your full name has been changed." : "Numele tău complet a fost schimbat.",
    "Unable to change full name" : "Nu s-a putut schimba numele complet",
    "Redis" : "Redis",
    "__language_name__" : "_language_name_",
    "Language changed" : "Limba a fost schimbată",
    "Invalid request" : "Cerere eronată",
    "Admins can't remove themself from the admin group" : "Administratorii nu se pot șterge singuri din grupul adminnistrativ",
    "Unknown user" : "Utilizator necunoscut",
    "Couldn't remove app." : "Nu s-a putut înlătura aplicația.",
    "Official" : "Oficial",
    "Approved" : "Aprobat",
    "All" : "Toate ",
    "Enabled" : "Activat",
    "Not enabled" : "Dezactivat",
    "No apps found for your version" : "Nu au fost găsite aplicații pentru versiunea ta",
    "The app will be downloaded from the app store" : "Aplicația va fi descărcată din magazin",
    "Please wait...." : "Aşteptaţi vă rog....",
    "Error while disabling app" : "Eroare în timpul dezactivării aplicației",
    "Disable" : "Dezactivați",
    "Enable" : "Activare",
    "Error while enabling app" : "Eroare în timpul activării applicației",
    "Updating...." : "Actualizare în curs....",
    "Error while updating app" : "Eroare în timpul actualizării aplicaţiei",
    "Updated" : "Actualizat",
    "Uninstalling ...." : "Dezinstalaza ....",
    "Error while uninstalling app" : "Eroare la dezinstalarea aplicației",
    "Uninstall" : "Dezinstalați",
    "App update" : "Actualizare aplicație",
    "Experimental" : "Experimental",
    "Add trusted domain" : "Adaugă domeniu de încredere",
    "Migration in progress. Please wait until the migration is finished" : "Migrare în progres. Așteaptă până când migrarea este finalizată",
    "Migration started …" : "Migrarea a început...",
    "Valid until {date}" : "Valabil până la {date}",
    "Delete" : "Șterge",
    "Disconnect" : "Deconectare",
    "Sending..." : "Se expediază...",
    "An error occurred: {message}" : "A apărut o eroare: {message}",
    "Select a profile picture" : "Selectează o imagine de profil",
    "Very weak password" : "Parolă foarte slabă",
    "Weak password" : "Parolă slabă",
    "So-so password" : "Parolă medie",
    "Good password" : "Parolă bună",
    "Strong password" : "Parolă puternică",
    "Groups" : "Grupuri",
    "Unable to delete {objName}" : "Nu s-a putut șterge {objName}",
    "Error creating group: {message}" : "Eroare la crearea grupului: {message}",
    "A valid group name must be provided" : "Trebuie furnizat un nume de grup valid",
    "deleted {groupName}" : "{groupName} s-a șters",
    "undo" : "desfă",
    "never" : "niciodată",
    "deleted {userName}" : "{userName} șters",
    "add group" : "adăugaţi grupul",
    "enabled" : "activat",
    "disabled" : "dezactivat",
    "no group" : "niciun grup",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Schimbarea parolei va rezulta în pierderea datelor deoarece recuperarea acestora nu este disponibilă pentru acest utilizator",
    "A valid username must be provided" : "Trebuie să furnizaţi un nume de utilizator valid",
    "Error creating user: {message}" : "Eroare la crearea utilizatorului: {message}",
    "A valid password must be provided" : "Trebuie să furnizaţi o parolă validă",
    "A valid email must be provided" : "Trebuie furnizată o adresă email validă",
    "Cheers!" : "Noroc!",
    "User documentation" : "Documentație utilizator",
    "Administrator documentation" : "Documentație pentru administrare",
    "Online documentation" : "Documentație online",
    "Forum" : "Forum",
    "Commercial support" : "Suport comercial",
    "Developer documentation" : "Documentație pentru dezvoltatori",
    "by %s" : "de %s",
    "%s-licensed" : "%s-licențiat",
    "Documentation:" : "Documentație:",
    "Admin documentation" : "Documentație pentru administrare",
    "Report a bug" : "Raportează un defect",
    "Show description …" : "Arată descriere ...",
    "Hide description …" : "Ascunde descriere ...",
    "Enable only for specific groups" : "Activează doar pentru grupuri specifice",
    "Uninstall App" : "Dezinstalează aplicația",
    "Cron" : "Cron",
    "Open documentation" : "Deschide documentația",
    "Execute one task with each page loaded" : "Execută o sarcină la fiecare pagină încărcată",
    "SSL Root Certificates" : "Certificate SSL rădăcină",
    "Common Name" : "Nume comun",
    "Valid until" : "Valabil până la",
    "Issued By" : "Emis de",
    "Valid until %s" : "Valabil până la %s",
    "Import root certificate" : "Importă certificat rădăcină",
    "Server-side encryption" : "Criptare la nivel de server",
    "Enable server-side encryption" : "Activează criptarea pe server",
    "Please read carefully before activating server-side encryption: " : "Citește cu atenție înainte să activezi criptarea pe server:",
    "This is the final warning: Do you really want to enable encryption?" : "Aceasta este avertizarea finală: Chiar vrei să activezi criptarea?",
    "Enable encryption" : "Activează criptarea",
    "Select default encryption module:" : "Selectează modulul implicit de criptare:",
    "Start migration" : "Pornește migrarea",
    "Sharing" : "Partajare",
    "Allow apps to use the Share API" : "Permite aplicațiilor să folosească API-ul de partajare",
    "Allow users to share via link" : "Permite utilizatorilor să partajeze via link",
    "Allow public uploads" : "Permite încărcări publice",
    "Enforce password protection" : "Impune protecția prin parolă",
    "Set default expiration date" : "Setează data implicită de expirare",
    "Allow users to send mail notification for shared files" : "Permite utilizatorilor sa expedieze notificări prin e-mail pentru dosarele comune",
    "Expire after " : "Expiră după",
    "days" : "zile",
    "Enforce expiration date" : "Impune data de expirare",
    "Allow resharing" : "Permite repartajarea",
    "Allow sharing with groups" : "Permite partajarea cu grupuri",
    "Exclude groups from sharing" : "Exclude grupuri de la partajare",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Tot (erori fatale, erori, avertizări, informări, depanare)",
    "Info, warnings, errors and fatal issues" : "Informări, avertizări, erori și erori fatale",
    "Warnings, errors and fatal issues" : "Avertizări, erori și erori fatale",
    "Errors and fatal issues" : "Erori și erori fatale",
    "Fatal issues only" : "Doar erori fatale",
    "Log" : "Jurnal de activitate",
    "What to log" : "Ce să loghezi",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Fișierul cu loguri este mai mare de 100 MB. Descărcarea acestuia ar putea dura ceva timp!",
    "None" : "Niciuna",
    "Login" : "Autentificare",
    "NT LAN Manager" : "NT LAN Manager",
    "Email server" : "Server de email",
    "Send mode" : "Modul de expediere",
    "Encryption" : "Încriptare",
    "From address" : "De la adresa",
    "mail" : "poștă",
    "Authentication method" : "Modul de autentificare",
    "Authentication required" : "Autentificare necesară",
    "Server address" : "Adresa server-ului",
    "Port" : "Portul",
    "Credentials" : "Detalii de autentificare",
    "SMTP Username" : "Nume utilizator SMTP",
    "SMTP Password" : "Parolă SMTP",
    "Store credentials" : "Stochează datele de autentificare",
    "Test email settings" : "Verifică setările de e-mail",
    "Send email" : "Expediază mesajul",
    "Security & setup warnings" : "Alerte de securitate & configurare",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Modulul PHP \"Fileinfo\" lipsește. Va recomandam sa activaţi acest modul pentru a obține cele mai bune rezultate cu detectarea mime-type.",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite e folosit ca o bază de date. Pentru instalări mari recomandăm folosirea unei alte baze de date.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "În special atunci când este folosit clientul desktop pentru sincronizarea fișierelor, utilizarea SQLite este nerecomandată.",
    "All checks passed." : "Toate verificările s-au terminat fără erori.",
    "Tips & tricks" : "Tips & tricks",
    "How to do backups" : "Cum să faci copii de rezervă",
    "Advanced monitoring" : "Monitorizare avansată",
    "Get the apps to sync your files" : "Ia acum aplicatia pentru sincronizarea fisierelor ",
    "Desktop client" : "Client Desktop",
    "Android app" : "Aplicatie Android",
    "iOS app" : "Aplicație iOS",
    "Profile picture" : "Imagine de profil",
    "Upload new" : "Încarcă una nouă",
    "Remove image" : "Înlătură imagine",
    "png or jpg, max. 20 MB" : "png sau jpg, max. 20 MB",
    "Cancel" : "Anulare",
    "Full name" : "Nume complet",
    "Email" : "Email",
    "Your email address" : "Adresa ta de email",
    "Password" : "Parolă",
    "Unable to change your password" : "Imposibil de-ați schimbat parola",
    "Current password" : "Parola curentă",
    "New password" : "Noua parolă",
    "Change password" : "Schimbă parola",
    "Language" : "Limba",
    "Help translate" : "Ajută la traducere",
    "Unlimited" : "Nelimitată",
    "Sessions" : "Sesiuni",
    "Most recent activity" : "Cea mai recentă activitate",
    "App passwords" : "Parole aplicații",
    "Name" : "Nume",
    "Username" : "Utilizator",
    "Version" : "Versiunea",
    "Personal" : "Personal",
    "Admin" : "Administrator",
    "Error" : "Eroare",
    "E-Mail" : "Email",
    "Create" : "Creează",
    "Admin Recovery Password" : "Parolă de recuperare a Administratorului",
    "Enter the recovery password in order to recover the users files during password change" : "Introdu parola de recuperare pentru a recupera fișierele utilizatorilor în timpul schimbării parolei",
    "Group" : "Grup",
    "Admins" : "Administratori",
    "Default Quota" : "Cotă implicită",
    "Other" : "Altele",
    "Full Name" : "Nume complet",
    "Group Admin for" : "Administrator de grup pentru",
    "Quota" : "Cotă",
    "Last Login" : "Ultima autentificare",
    "change full name" : "schimbă numele complet",
    "set new password" : "setează parolă nouă",
    "change email address" : "schimbă adresa email",
    "Default" : "Implicită",
    "The new password can not be the same as the previous one" : "Noua parolă nu poate fi aceeași ca cea precedentă",
    "Change email" : "Schimbă adresa email",
    "Share" : "Partajează",
    "APCu" : "APCu",
    "Visit website" : "Vizitează website",
    "Allow users to share file via social media" : "Permite utilizatorilor să partajeze fișier via rețele sociale",
    "Plain" : "Simplu",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "System Status" : "Stare Sistem",
    "Domain" : "Domeniu",
    "Add" : "Adaugă",
    "Select from Files" : "Alege din Fișiere",
    "Choose as profile picture" : "Alege ca și imagine de profil",
    "App name" : "Nume aplicație",
    "Done" : "Gata",
    "Error: this app cannot be enabled because it makes the server unstable" : "Eroare: această aplicație nu poate fi activată, deoarece face serverul instabil",
    "Apps Management" : "Administrarea aplicațiilor",
    "Show enabled apps" : "Arată aplicații activate",
    "Show disabled apps" : "Arată aplicații dezactivate",
    "Performance tuning" : "Tuning de performanță",
    "Improving the config.php" : "Îmbunătățirea config.php",
    "%s password changed successfully" : "parola %s a fost schimbată cu succes",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Aplicațiile oficiale sunt dezvoltate de și în cadrul comunității ownCloud. Acestea oferă funcționalitate centrală pentru ownCloud și sunt gata pentru utilizare în producție.",
    "Download logfile (%s)" : "Descarcă fișierul cu loguri (%s)",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "A intervenit o eroare. Te rugăm încarcă un certificat PEM codat ASCII",
    "Failed to change the email address." : "Schimbarea adresei de e-mail a eșuat.",
    "Email has been changed successfully." : "Adresa email a fost schimbată cu succes.",
    "User {uid} has been {state}!" : "Utilizatorul {uid} a fost {state}!",
    "Password successfully changed" : "Parola a fost schimbată cu succes",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Furnizează o parolă de recuperare pentru administrator; În caz contrar, toate datele de utilizator vor fi pierdute.",
    "Couldn't change the email address because the user does not exist" : "Nu am putut modifica adresa de e-mail deoarece utilizatorul nu există",
    "Couldn't change the email address because the token is invalid" : "Nu am putut modifica adresa de e-mail, deoarece tokenul nu este valid",
    "No email was sent because you already sent one recently. Please try again later." : "Nu a fost trimis niciun e-mail deoarece ai trimis deja unul recent. Te rugăm să încerci din nou mai târziu.",
    "%s email address confirm" : "confirmare adresă e-mail %s",
    "Couldn't send email address change confirmation mail. Please contact your administrator." : "Nu am putut trimite e-mail de confirmare a schimbării adresei de e-mail. Contactează administratorul tău.",
    "%s email address changed successfully" : "adresa e-mail %s a fost schimbată cu succes",
    "Couldn't send email address change notification mail. Please contact your administrator." : "Nu am putut trimite e-mail de notificare a schimbării adresei de e-mail. Contactează administratorul tău.",
    "Unable to enable/disable user." : "Imposibil de activat/dezactivat utilizator.",
    "Users" : "Utilizatori",
    "Show email address" : "Arată adresa email",
    "Add Group" : "Adaugă grup"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> owncloud-10.4.0.zip: owncloud/settings/l10n/ro.js <==
OC.L10N.register(
    "settings",
    {
    "No user supplied" : "Nu a fost furnizat niciun utilizator",
    "Authentication error" : "Eroare la autentificare",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Furnizează o parolă de recuperare pentru administrator; În caz contrar, toate datele de utilizator vor fi pierdute.",
    "Wrong admin recovery password. Please check the password and try again." : "Parolă administrativă de recuperare greșită. Verifică parola și încearcă din nou.",
    "Unable to change password" : "Imposibil de schimbat parola",
    "%s password changed successfully" : "parola %s a fost schimbată cu succes",
    "Couldn't send reset email. Please contact your administrator." : "Expedierea email-ului de resetare a eşuat. Vă rugăm să contactaţi administratorul dvs.",
    "Group already exists." : "Grupul există deja.",
    "Unable to add group." : "Nu se poate adăuga grupul.",
    "Unable to delete group." : "Nu se poate șterge grupul.",
    "Saved" : "Salvat",
    "log-level out of allowed range" : "NIvelul de logare este în afara plajei admise",
    "test email settings" : "verifică setările de e-mail",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : " A apărut o problemă la trimiterea emailului. Verifică-ți setărie. (Eroare: %s)",
    "Email sent" : "Mesajul a fost expediat",
    "You need to set your user email before being able to send test emails." : "Trebuie să îți setezi emailul de utilizator înainte de a putea să trimiți emailuri.",
    "Couldn't change the email address because the user does not exist" : "Nu am putut modifica adresa de e-mail deoarece utilizatorul nu există",
    "Couldn't change the email address because the token is invalid" : "Nu am putut modifica adresa de e-mail, deoarece tokenul nu este valid",
    "Your %s account was created" : "Contul tău %s a fost creat",
    "Invalid mail address" : "Adresa mail invalidă",
    "A user with that name already exists." : "Există deja un utilizator cu acest nume.",
    "Unable to create user." : "Imposibil de creat utilizatorul.",
    "Unable to delete user." : "Imposibil de șters utilizatorul.",
    "Forbidden" : "Interzis",
    "Invalid user" : "Utilizator invalid",
    "Unable to change mail address" : "Nu s-a putut schimba adresa email",
    "Email has been changed successfully." : "Adresa email a fost schimbată cu succes.",
    "No email was sent because you already sent one recently. Please try again later." : "Nu a fost trimis niciun e-mail deoarece ai trimis deja unul recent. Te rugăm să încerci din nou mai târziu.",
    "Your full name has been changed." : "Numele tău complet a fost schimbat.",
    "Unable to change full name" : "Nu s-a putut schimba numele complet",
    "%s email address confirm" : "confirmare adresă e-mail %s",
    "Couldn't send email address change confirmation mail. Please contact your administrator." : "Nu am putut trimite e-mail de confirmare a schimbării adresei de e-mail. Contactează administratorul tău.",
    "%s email address changed successfully" : "adresa e-mail %s a fost schimbată cu succes",
    "Couldn't send email address change notification mail. Please contact your administrator." : "Nu am putut trimite e-mail de notificare a schimbării adresei de e-mail. Contactează administratorul tău.",
    "Unable to enable/disable user." : "Imposibil de activat/dezactivat utilizator.",
    "Create" : "Crează",
    "Delete" : "Șterge",
    "Share" : "Partajează",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Language changed" : "Limba a fost schimbată",
    "Invalid request" : "Solicitare eronată",
    "Admins can't remove themself from the admin group" : "Administratorii nu se pot șterge singuri din grupul adminnistrativ",
    "Unknown user" : "Utilizator necunoscut",
    "Couldn't remove app." : "Nu s-a putut înlătura aplicația.",
    "Official" : "Oficial",
    "Approved" : "Aprobat",
    "All" : "Toate ",
    "Enabled" : "Activat",
    "Not enabled" : "Dezactivat",
    "No apps found for your version" : "Nu au fost găsite aplicații pentru versiunea ta",
    "The app will be downloaded from the app store" : "Aplicația va fi descărcată din magazin",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Aplicațiile oficiale sunt dezvoltate de și în cadrul comunității ownCloud. Acestea oferă funcționalitate centrală pentru ownCloud și sunt gata pentru utilizare în producție.",
    "Please wait...." : "Aşteptaţi vă rog....",
    "Error while disabling app" : "Eroare în timpul dezactivării aplicației",
    "Disable" : "Dezactivați",
    "Enable" : "Activare",
    "Error while enabling app" : "Eroare în timpul activării applicației",
    "Error: this app cannot be enabled because it makes the server unstable" : "Eroare: această aplicație nu poate fi activată, deoarece face serverul instabil",
    "Updating...." : "Actualizare în curs....",
    "Error while updating app" : "Eroare în timpul actualizării aplicaţiei",
    "Updated" : "Actualizat",
    "Uninstalling ...." : "Dezinstalează ....",
    "Error while uninstalling app" : "Eroare la dezinstalarea aplicației",
    "Uninstall" : "Dezinstalează",
    "App update" : "Actualizare aplicație",
    "Experimental" : "Experimental",
    "Migration in progress. Please wait until the migration is finished" : "Migrare în progres. Așteaptă până când migrarea este finalizată",
    "Migration started …" : "Migrarea a început...",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "A intervenit o eroare. Te rugăm încarcă un certificat PEM codat ASCII",
    "Valid until {date}" : "Valabil până la {date}",
    "Disconnect" : "Deconectare",
    "Sending..." : "Se expediază...",
    "Failed to change the email address." : "Schimbarea adresei de e-mail a eșuat.",
    "An error occurred: {message}" : "A apărut o eroare: {message}",
    "Select a profile picture" : "Selectează o imagine de profil",
    "Very weak password" : "Parolă foarte slabă",
    "Weak password" : "Parolă slabă",
    "So-so password" : "Parolă medie",
    "Good password" : "Parolă bună",
    "Strong password" : "Parolă puternică",
    "Groups" : "Grupuri",
    "Unable to delete {objName}" : "Nu s-a putut șterge {objName}",
    "Error creating group: {message}" : "Eroare la crearea grupului: {message}",
    "A valid group name must be provided" : "Trebuie furnizat un nume de grup valid",
    "deleted {groupName}" : "{groupName} s-a șters",
    "undo" : "desfă",
    "never" : "niciodată",
    "deleted {userName}" : "{userName} șters",
    "add group" : "adăugaţi grupul",
    "enabled" : "activat",
    "disabled" : "dezactivat",
    "User {uid} has been {state}!" : "Utilizatorul {uid} a fost {state}!",
    "no group" : "niciun grup",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Schimbarea parolei va rezulta în pierderea datelor deoarece recuperarea acestora nu este disponibilă pentru acest utilizator",
    "Password successfully changed" : "Parola a fost schimbată cu succes",
    "A valid username must be provided" : "Trebuie să furnizaţi un nume de utilizator valid",
    "Error creating user: {message}" : "Eroare la crearea utilizatorului: {message}",
    "A valid password must be provided" : "Trebuie să furnizaţi o parolă validă",
    "A valid email must be provided" : "Trebuie furnizată o adresă email validă",
    "Cheers!" : "Noroc!",
    "User documentation" : "Documentație utilizator",
    "Administrator documentation" : "Documentație pentru administrare",
    "Developer documentation" : "Documentație pentru dezvoltatori",
    "Online documentation" : "Documentație online",
    "Forum" : "Forum",
    "Commercial support" : "Suport comercial",
    "Language" : "Limba",
    "Apps Management" : "Administrarea aplicațiilor",
    "by %s" : "de %s",
    "%s-licensed" : "%s-licențiat",
    "Documentation:" : "Documentație:",
    "Admin documentation" : "Documentație pentru administrare",
    "Visit website" : "Vizitează website",
    "Report a bug" : "Raportează un defect",
    "Show description …" : "Arată descriere ...",
    "Hide description …" : "Ascunde descriere ...",
    "Enable only for specific groups" : "Activează doar pentru grupuri specifice",
    "Uninstall App" : "Dezinstalează aplicația",
    "Show enabled apps" : "Arată aplicații activate",
    "Show disabled apps" : "Arată aplicații dezactivate",
    "Cron" : "Cron",
    "Open documentation" : "Deschide documentația",
    "Execute one task with each page loaded" : "Execută o sarcină la fiecare pagină încărcată",
    "SSL Root Certificates" : "Certificate SSL rădăcină",
    "Common Name" : "Nume comun",
    "Valid until" : "Valabil până la",
    "Issued By" : "Emis de",
    "Valid until %s" : "Valabil până la %s",
    "Import root certificate" : "Importă certificat rădăcină",
    "Server-side encryption" : "Criptare la nivel de server",
    "Enable server-side encryption" : "Activează criptarea pe server",
    "Please read carefully before activating server-side encryption: " : "Citește cu atenție înainte să activezi criptarea pe server:",
    "This is the final warning: Do you really want to enable encryption?" : "Aceasta este avertizarea finală: Chiar vrei să activezi criptarea?",
    "Enable encryption" : "Activează criptarea",
    "Select default encryption module:" : "Selectează modulul implicit de criptare:",
    "Start migration" : "Pornește migrarea",
    "Sharing" : "Partajare",
    "Allow apps to use the Share API" : "Permite aplicațiilor să folosească API-ul de partajare",
    "Allow users to share via link" : "Permite utilizatorilor să partajeze via link",
    "Allow public uploads" : "Permite încărcări publice",
    "Set default expiration date" : "Setează data implicită de expirare",
    "Expire after " : "Expiră după",
    "days" : "zile",
    "Allow users to send mail notification for shared files" : "Permite utilizatorilor sa expedieze notificări prin e-mail pentru dosarele comune",
    "Allow users to share file via social media" : "Permite utilizatorilor să partajeze fișier via rețele sociale",
    "Allow resharing" : "Permite repartajarea",
    "Allow sharing with groups" : "Permite partajarea cu grupuri",
    "Exclude groups from sharing" : "Exclude grupuri de la partajare",
    "None" : "Niciuna",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Tot (erori fatale, erori, avertizări, informări, depanare)",
    "Info, warnings, errors and fatal issues" : "Informări, avertizări, erori și erori fatale",
    "Warnings, errors and fatal issues" : "Avertizări, erori și erori fatale",
    "Errors and fatal issues" : "Erori și erori fatale",
    "Fatal issues only" : "Doar erori fatale",
    "Log" : "Jurnal de activitate",
    "What to log" : "Ce să loghezi",
    "Download logfile (%s)" : "Descarcă fișierul cu loguri (%s)",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Fișierul cu loguri este mai mare de 100 MB. Descărcarea acestuia ar putea dura ceva timp!",
    "Login" : "Autentificare",
    "Plain" : "Simplu",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Server de email",
    "Send mode" : "Modul de expediere",
    "Encryption" : "Încriptare",
    "From address" : "De la adresa",
    "mail" : "poștă",
    "Authentication method" : "Modul de autentificare",
    "Authentication required" : "Autentificare necesară",
    "Server address" : "Adresa server-ului",
    "Port" : "Portul",
    "Credentials" : "Detalii de autentificare",
    "SMTP Username" : "Nume utilizator SMTP",
    "SMTP Password" : "Parolă SMTP",
    "Store credentials" : "Stochează datele de autentificare",
    "Test email settings" : "Verifică setările de e-mail",
    "Send email" : "Expediază mesajul",
    "Security & setup warnings" : "Alerte de securitate & configurare",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Modulul PHP \"Fileinfo\" lipsește. Va recomandam sa activaţi acest modul pentru a obține cele mai bune rezultate cu detectarea mime-type.",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite e folosit ca o bază de date. Pentru instalări mari recomandăm folosirea unei alte baze de date.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "În special atunci când este folosit clientul desktop pentru sincronizarea fișierelor, utilizarea SQLite este nerecomandată.",
    "All checks passed." : "Toate verificările s-au terminat fără erori.",
    "System Status" : "Stare Sistem",
    "Tips & tricks" : "Tips & tricks",
    "How to do backups" : "Cum să faci copii de rezervă",
    "Performance tuning" : "Tuning de performanță",
    "Improving the config.php" : "Îmbunătățirea config.php",
    "Get the apps to sync your files" : "Ia acum aplicatia pentru sincronizarea fisierelor ",
    "Desktop client" : "Client Desktop",
    "Android app" : "Aplicatie Android",
    "iOS app" : "Aplicație iOS",
    "Domain" : "Domeniu",
    "Add" : "Adaugă",
    "Profile picture" : "Imagine de profil",
    "Upload new" : "Încarcă una nouă",
    "Select from Files" : "Alege din Fișiere",
    "Remove image" : "Înlătură imagine",
    "png or jpg, max. 20 MB" : "png sau jpg, max. 20 MB",
    "Cancel" : "Anulare",
    "Choose as profile picture" : "Alege ca și imagine de profil",
    "Full name" : "Nume complet",
    "Email" : "Email",
    "Your email address" : "Adresa ta de email",
    "Change email" : "Schimbă adresa email",
    "Password" : "Parolă",
    "Unable to change your password" : "Imposibil de-ați schimbat parola",
    "Current password" : "Parola curentă",
    "New password" : "Noua parolă",
    "Change password" : "Schimbă parola",
    "Help translate" : "Ajută la traducere",
    "Sessions" : "Sesiuni",
    "Most recent activity" : "Cea mai recentă activitate",
    "Name" : "Nume",
    "App name" : "Nume aplicație",
    "Username" : "Nume utilizator",
    "Done" : "Gata",
    "Version" : "Versiunea",
    "New Password" : "Noua parolă",
    "Personal" : "Personal",
    "Admin" : "Administrator",
    "Other" : "Altele",
    "Settings" : "Setări",
    "Show email address" : "Arată adresa email",
    "E-Mail" : "Email",
    "Admin Recovery Password" : "Parolă de recuperare a Administratorului",
    "Enter the recovery password in order to recover the users files during password change" : "Introdu parola de recuperare pentru a recupera fișierele utilizatorilor în timpul schimbării parolei",
    "Add Group" : "Adaugă grup",
    "Group" : "Grup",
    "Admins" : "Administratori",
    "Default Quota" : "Cotă implicită",
    "Unlimited" : "Nelimitată",
    "Full Name" : "Nume complet",
    "Group Admin for" : "Administrator de grup pentru",
    "Quota" : "Cotă",
    "Last Login" : "Ultima autentificare",
    "change full name" : "schimbă numele complet",
    "set new password" : "setează parolă nouă",
    "change email address" : "schimbă adresa email",
    "Default" : "Implicită"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
